# Generated by Django 4.2.1 on 2024-03-08 07:25

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoauthtoken', '0002_alter_tokenuser_email'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tokenuser',
            name='phone_number',
            field=models.CharField(max_length=17, null=True, validators=[django.core.validators.RegexValidator(message="Phone numbers must be in International format: '+14169058762'. Up to 15 digits ", regex='^\\+?1?\\d{9,15}')]),
        ),
    ]
